==> media_crowdriff-1.0.0.tar.gz: media_crowdriff/src/Plugin/Field/FieldFormatter/MediaCrowdriffEmbedFormatter.php <==
<?php

declare(strict_types=1);

namespace Drupal\media_crowdriff\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'media_crowdriff' formatter.
 *
 * @FieldFormatter(
 *   id = "media_crowdriff",
 *   label = @Translation("Media Crowdriff"),
 *   field_types = {
 *     "string_long"
 *   }
 * )
 */
class MediaCrowdriffEmbedFormatter extends FormatterBase {

  const CROWDRIFF_SCRIPT_URL = 'https://starling.crowdriff.com/js/crowdriff.js';

  /**
   * Gets the regex pattern for matching Crowdriff embed IDs.
   *
   * @return string
   *   Returns a string containing the regex pattern.
   */
  public static function getIdRegexPattern() {
    return '/^cr-init__\w+/';
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    foreach ($items as $delta => $item) {
      /** @var \Drupal\Core\Field\FieldItemInterface $item */
      if ($item->isEmpty()) {
        continue;
      }

      $matches = [];
      $pattern = static::getIdRegexPattern();
      preg_match_all($pattern, $item->value, $matches);

      if (empty($matches[0][0])) {
        continue;
      }

      $elements[$delta] = [
        '#theme' => 'media_crowdriff',
        '#crowdriff' => $matches[0][0],
        '#script' => self::CROWDRIFF_SCRIPT_URL,
        '#title' => $item->getParent()->getParent()->get('name')->value,
        '#width' => $this->getSetting('width'),
        '#height' => $this->getSetting('height'),
      ];
    }
    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'width' => '100%',
      'height' => '900px',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return parent::settingsForm($form, $form_state) + [
      'width' => [
        '#type' => 'textfield',
        '#title' => $this->t('Width'),
        '#default_value' => $this->getSetting('width'),
        '#size' => 5,
        '#maxlength' => 10,
        '#description' => $this->t('Valid css unit e.g. 500px, 100%, etc.'),
      ],
      'height' => [
        '#type' => 'textfield',
        '#title' => $this->t('Height'),
        '#default_value' => $this->getSetting('height'),
        '#size' => 5,
        '#maxlength' => 10,
        '#description' => $this->t('Valid css unit e.g. 500px, 100%, etc.'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $summary[] = $this->t('Iframe size: %width , %height.', [
      '%width' => $this->getSetting('width'),
      '%height' => $this->getSetting('height'),
    ]);
    return $summary;
  }

}

==> media_crowdriff-1.1.1.tar.gz: media_crowdriff/src/Plugin/Field/FieldFormatter/MediaCrowdriffEmbedFormatter.php <==
<?php

declare(strict_types=1);

namespace Drupal\media_crowdriff\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'media_crowdriff' formatter.
 *
 * @FieldFormatter(
 *   id = "media_crowdriff",
 *   label = @Translation("Media Crowdriff"),
 *   field_types = {
 *     "string_long"
 *   }
 * )
 */
class MediaCrowdriffEmbedFormatter extends FormatterBase {

  const CROWDRIFF_SCRIPT_URL = 'https://starling.crowdriff.com/js/crowdriff.js';

  /**
   * The regex pattern for matching Crowdriff embed IDs.
   */
  public const REGEX_PATTERN = '/(cr-init__|cr__init-)[a-z0-9]{8,}/';

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    foreach ($items as $delta => $item) {
      /** @var \Drupal\Core\Field\FieldItemInterface $item */
      if ($item->isEmpty()) {
        continue;
      }

      $matches = [];
      if (!preg_match(static::REGEX_PATTERN, $item->value, $matches)) {
        continue;
      }

      $elements[$delta] = [
        '#theme' => 'media_crowdriff',
        '#crowdriff' => $matches[0],
        '#script' => self::CROWDRIFF_SCRIPT_URL,
        '#title' => $item->getParent()->getParent()->get('name')->value,
        '#width' => $this->getSetting('width'),
        '#height' => $this->getSetting('height'),
      ];
    }
    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'width' => '100%',
      'height' => '900px',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return parent::settingsForm($form, $form_state) + [
      'width' => [
        '#type' => 'textfield',
        '#title' => $this->t('Width'),
        '#default_value' => $this->getSetting('width'),
        '#size' => 5,
        '#maxlength' => 10,
        '#description' => $this->t('Valid css unit e.g. 500px, 100%, etc.'),
      ],
      'height' => [
        '#type' => 'textfield',
        '#title' => $this->t('Height'),
        '#default_value' => $this->getSetting('height'),
        '#size' => 5,
        '#maxlength' => 10,
        '#description' => $this->t('Valid css unit e.g. 500px, 100%, etc.'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $summary[] = $this->t('Iframe size: %width , %height.', [
      '%width' => $this->getSetting('width'),
      '%height' => $this->getSetting('height'),
    ]);
    return $summary;
  }

}
